@@ -545,7 +545,10 @@ class ImageReader(object):
         self.using_temp_file = False
         if url is not None and url.lower().startswith(file_scheme):
             utf8_url = urllib.url2pathname(url[len(file_scheme):])
-            path = unicode(utf8_url, 'utf-8')
+            if isinstance(utf8_url, str):
+                path = unicode(utf8_url, 'utf-8')
+            else:
+                path = utf8_url
         self.path = path
         if path is None:
             if url.lower().startswith("omero:"):
@@ -790,7 +793,9 @@ class ImageReader(object):
         elif self.rdr.isRGB() and self.rdr.isInterleaved():
             index = self.rdr.getIndex(z,0,t)
             image = np.frombuffer(self.rdr.openBytes(index), dtype)
-            image.shape = (height, width, 3)
+            image.shape = (height, width, self.rdr.getSizeC())
+            if image.shape[2] > 3:
+                image = image[:, :, :3]
         elif c is not None and self.rdr.getRGBChannelCount() == 1:
             index = self.rdr.getIndex(z,c,t)
             image = np.frombuffer(self.rdr.openBytes(index), dtype)
